@@ -435,6 +435,47 @@ class DatePoint(AbstractModel):
         
 
 
+class DeleteEndPointRequest(AbstractModel):
+    """DeleteEndPoint请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param EndPointId: 终端节点ID
+        :type EndPointId: str
+        """
+        self.EndPointId = None
+
+
+    def _deserialize(self, params):
+        self.EndPointId = params.get("EndPointId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DeleteEndPointResponse(AbstractModel):
+    """DeleteEndPoint返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DeletePrivateDNSAccountRequest(AbstractModel):
     """DeletePrivateDNSAccount请求参数结构体
 
